0.2.28 (2024-03-17)
-------------------

Feed performance improvements.

- #118 Fix performance for feeds with many items / images
- #121 Add support for `Wagtail 6 <https://docs.wagtail.org/en/latest/releases/6.0.html>`_.
  - dropped support for Wagtail 4 and Django < 4.2
- some pre-commit and javascript updates
